﻿/// <reference path="JsDiagram-vsdoc.js" />
var DiagramView = MindFusion.Diagramming.DiagramView;
var Events = MindFusion.Diagramming.Events;
var Diagram = MindFusion.Diagramming.Diagram;
var DiagramLink = MindFusion.Diagramming.DiagramLink;
var ShapeNode = MindFusion.Diagramming.ShapeNode;
var AnchorPattern = MindFusion.Diagramming.AnchorPattern;
var AnchorPoint = MindFusion.Diagramming.AnchorPoint;
var MarkStyle = MindFusion.Diagramming.MarkStyle;
var GlassEffect = MindFusion.Diagramming.GlassEffect;
var Style = MindFusion.Diagramming.Style;
var Theme = MindFusion.Diagramming.Theme;

var Rect = MindFusion.Drawing.Rect;

var diagram = null;
var diagramView = null;
var bounds = new Rect(0, 0, 30, 6);
var colors = ["#5b9bd5", "#ed7d31", "#e0a900"];

var decision1In3Out, apat2;

document.addEventListener("DOMContentLoaded", function ()
{
	// create a Diagram component that wraps the "diagram" canvas
	diagramView = DiagramView.create(document.getElementById("diagram_canvas"));
	diagram = diagramView.diagram;
	diagram.bounds = new Rect(5, 5, 2000, 1000);
    diagram.linkHeadShapeSize = 2;
    diagram.defaultShape = "Rectangle";
    diagram.routeLinks = true;
    diagram.roundedLinks = true;
    diagram.showGrid = false;
    diagram.backBrush = "#e0e9e9";

    var theme = new Theme();
	
    var shapeNodeStyle = new Style();
    shapeNodeStyle.brush = { type: 'LinearGradientBrush', color1: '#e0e9e9', color2: '#616a7f', angle: 90 };
    shapeNodeStyle.stroke = "#FFFFFF";
	//shapeNodeStyle.strokeThickness = 1;
    shapeNodeStyle.textColor = "#585A5C";
    shapeNodeStyle.fontName = "Verdana";
    shapeNodeStyle.fontSize = 3;
    shapeNodeStyle.backBrush = "#e0e9e9"; 
    theme.styles.set("std:ShapeNode", shapeNodeStyle);
	
	var linkStyle = new Style();
    linkStyle.brush = { type: 'SolidBrush', color: '#5b9bd5'};
    linkStyle.stroke = "#5b9bd5";
	//linkStyle.strokeThickness = 1;
    linkStyle.textColor = "#585A5C";
    linkStyle.fontName = "Verdana";
    linkStyle.fontSize = 3;
    linkStyle.backBrush = "#e0e9e9"; 
    theme.styles.set("std:DiagramLink", linkStyle);
	
	diagram.theme = theme;	
 
    diagram.backBrush = { type: 'SolidBrush', color: '#ebf3fa'};
	diagram.defaultShape = "Rectangle";
	
	for(var i = 0; i < 50; i++)
	{
		var colorIndex = Math.floor(Math.random() * 3);  
		var shape = diagram.factory.createShapeNode(new Rect(136, 36, 20, 10));
		shape.brush = { type: 'SolidBrush', color: colors[colorIndex] };
		if(i % 3   == 0)
		   shape.shape = 'Ellipse';
	     else 
		    shape.shape = 'Rectangle';
	    if( i % 7 == 0)
		{
			shape.bounds = new Rect(136, 36, 16, 8);	
		}
	
		
		shape.text = "Node " + (i + 1).toString();
		shape.textColor = "white";
	}
    
	diagram.nodes.forEach(function(node){
    
	var nodeIndex = Math.floor(Math.random() * 50);  
	
	var node2 = diagram.nodes[nodeIndex];
	var link = diagram.factory.createDiagramLink(node, node2);
	link.headShape = "Circle";
	
  })
  
  var layout = new MindFusion.Graphs.LayeredLayout();
	layout.direction = MindFusion.Graphs.LayoutDirection.LeftToRight;
	layout.siftingRounds = 0;
	layout.nodeDistance = 8;
	layout.layerDistance = 8;
	diagram.arrange(layout);
	
});

var dgrm = document.getElementById('diagram_canvas');


/* events fired on the draggable target */
dgrm.addEventListener('mousedown', function(e)
{
 if( e.ctrlKey)
	diagramView.behavior = MindFusion.Diagramming.Behavior.Pan;
 
}, false);

dgrm.addEventListener('mouseup', function(e)
{
 if( e.ctrlKey)
	diagramView.behavior = MindFusion.Diagramming.Behavior.LinkShapes;
 
}, false);


document.body.addEventListener('wheel', function(e)
{
	var zoom = diagramView.zoomFactor;
	zoom -= e.deltaY / 10;
	if (zoom > 10)
		diagramView.zoomFactor = zoom;

	e.preventDefault(); // do not scroll
}); 



